@@ -8,7 +8,7 @@ import numpy as np
 import sys
 import importlib.resources
 from urllib.parse import urlparse
-from veevanetwork.custom_exceptions.veevanetwork_exceptions import *
+from custom_exceptions.veevanetwork_exceptions import *
 
 class Vn:
     def __init__(self):
@@ -196,17 +196,22 @@ class Vn:
         
         """
         
+        
         url_parse = urlparse(networkURL)
         if len(url_parse.scheme) == 0:
             self.network_protocol = 'https'
-            if len(url_parse.params) > 0:
-                self.network_DNS = url_parse.params
-        
+            if len(url_parse.path) > 0:
+                self.network_DNS = url_parse.path
+                self.networkURL = self.network_protocol + '://' + url_parse.path
+
         if len(url_parse.scheme) > 0:
             self.network_protocol = url_parse.scheme
             if len(url_parse.netloc) > 0:
                 self.network_DNS = url_parse.netloc
-                self.networkURL = url_parse.geturl()
+                self.networkURL = url_parse.scheme + '://' + url_parse.netloc
+
+        if (self.networkURL is None) or (len(self.networkURL) == 0):
+            raise Exception('networkURL is required')
 
             
 
@@ -1362,8 +1367,8 @@ class Vn:
                 if api['request']['url'].keys().__contains__('raw'):
                     print_if("\n- Request url raw: ")
                     print_if(api['request']['url']['raw'])
-                    result['api_url'] = self.sub_request_params(api['request']['url']['raw']) ### Updating Result API URL
-                    request_params['url'] = self.sub_request_params(api['request']['url']['raw']) ### Updating Request URL
+                    result['api_url'] = self.sub_request_params(api['request']['url']['protocol'] + "://" + api['request']['url']['host'][0] + "/" + "/".join(api['request']['url']['path'])) ### Updating Result API URL
+                    request_params['url'] = self.sub_request_params(api['request']['url']['protocol'] + "://" + api['request']['url']['host'][0] + "/" + "/".join(api['request']['url']['path'])) ### Updating Request URL
                 else:
                     raise NetworkAPIRequestURLNotFound
 
